==> dde-launcher_4.4.5.5.orig.tar.xz: dde-launcher-4.4.5.5/translations/dde-launcher_zh_CN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_CN" version="2.1">
<context>
    <name>AppsManager</name>
    <message>
        <source>No search results</source>
        <translation>无搜索结果</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>网络应用</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>社交沟通</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>音乐欣赏</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>视频播放</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>图形图像</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>游戏娱乐</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>办公学习</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>阅读翻译</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>编程开发</translation>
    </message>
    <message>
        <source>System</source>
        <translation>系统管理</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>其他应用</translation>
    </message>
</context>
<context>
    <name>FullScreenFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation>您确定要卸载 %1 吗？</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>确定</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Remove from desktop</source>
        <translation>从桌面上移除</translation>
    </message>
    <message>
        <source>Remove from dock</source>
        <translation>从任务栏上移除</translation>
    </message>
    <message>
        <source>Uninstall</source>
        <translation>卸载</translation>
    </message>
    <message>
        <source>Open by proxy</source>
        <translation>使用代理打开</translation>
    </message>
    <message>
        <source>Disable display scaling</source>
        <translation>禁用屏幕缩放</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>打开</translation>
    </message>
    <message>
        <source>Send to desktop</source>
        <translation>发送到桌面</translation>
    </message>
    <message>
        <source>Send to dock</source>
        <translation>发送到任务栏</translation>
    </message>
    <message>
        <source>Remove from startup</source>
        <translation>取消开机自动启动</translation>
    </message>
    <message>
        <source>Add to startup</source>
        <translation>开机自动启动</translation>
    </message>
</context>
<context>
    <name>MiniCategoryWidget</name>
    <message>
        <source>All Apps</source>
        <translation>所有应用</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>网络应用</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>社交沟通</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>音乐欣赏</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>视频播放</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>图形图像</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>游戏娱乐</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>办公学习</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>阅读翻译</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>编程开发</translation>
    </message>
    <message>
        <source>System</source>
        <translation>系统管理</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>其他应用</translation>
    </message>
</context>
<context>
    <name>MiniFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation>您确定要卸载 %1 吗？</translation>
    </message>
    <message>
        <source>All dependencies will be removed together</source>
        <translation>所有依赖也会被一起移除 </translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>确定</translation>
    </message>
</context>
<context>
    <name>MiniFrameBottomBar</name>
    <message>
        <source>Computer</source>
        <translation>计算机</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>文档</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>视频</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>音乐</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>图片</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>下载</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>锁定</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>注销</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>重启</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>待机</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>关机</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>返回</translation>
    </message>
</context>
<context>
    <name>MiniFrameNavigation</name>
    <message>
        <source>Computer</source>
        <translation>计算机</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>音乐</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>关机</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>锁定</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>注销</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>重启</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>待机</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>返回</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>文档</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>视频</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>图片</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>下载</translation>
    </message>
</context>
<context>
    <name>MiniFrameRightBar</name>
    <message>
        <source>Computer</source>
        <translation>计算机</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>音乐</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>下载</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>帮助手册</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>关机</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>视频</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>图片</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>文档</translation>
    </message>
</context>
<context>
    <name>MiniFrameSwitchBtn</name>
    <message>
        <source>All Categories</source>
        <translation>所有分类</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>返回</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation>您确定要卸载 %1 吗？</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>确认</translation>
    </message>
</context>
</TS>

==> dde-launcher_5.0.14.orig.tar.xz: dde-launcher-5.0.14/translations/dde-launcher_zh_CN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_CN" version="2.1">
<context>
    <name>AppsManager</name>
    <message>
        <source>No search results</source>
        <translation>无搜索结果</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>网络应用</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>社交沟通</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>音乐欣赏</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>视频播放</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>图形图像</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>办公学习</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>阅读翻译</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>编程开发</translation>
    </message>
    <message>
        <source>System</source>
        <translation>系统管理</translation>
    </message>
    <message>
        <source>Games</source>
        <translation>游戏娱乐</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>其他应用</translation>
    </message>
</context>
<context>
    <name>FullScreenFrame</name>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>确定</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall %1 ?</source>
        <translation>您确定要卸载 %1 吗？</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Remove from desktop</source>
        <translation>从桌面上移除</translation>
    </message>
    <message>
        <source>Remove from dock</source>
        <translation>从任务栏上移除</translation>
    </message>
    <message>
        <source>Uninstall</source>
        <translation>卸载</translation>
    </message>
    <message>
        <source>Disable display scaling</source>
        <translation>禁用屏幕缩放</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>打开</translation>
    </message>
    <message>
        <source>Send to desktop</source>
        <translation>发送到桌面</translation>
    </message>
    <message>
        <source>Send to dock</source>
        <translation>发送到任务栏</translation>
    </message>
    <message>
        <source>Remove from startup</source>
        <translation>取消开机自动启动</translation>
    </message>
    <message>
        <source>Add to startup</source>
        <translation>开机自动启动</translation>
    </message>
    <message>
        <source>Use a proxy</source>
        <translation>使用代理</translation>
    </message>
</context>
<context>
    <name>MiniCategoryWidget</name>
    <message>
        <source>All Apps</source>
        <translation>所有应用</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>网络应用</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>社交沟通</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>音乐欣赏</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>视频播放</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>图形图像</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>游戏娱乐</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>办公学习</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>阅读翻译</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>编程开发</translation>
    </message>
    <message>
        <source>System</source>
        <translation>系统管理</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>其他应用</translation>
    </message>
</context>
<context>
    <name>MiniFrameBottomBar</name>
    <message>
        <source>Computer</source>
        <translation>计算机</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>文档</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>视频</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>音乐</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>图片</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>下载</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>锁定</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>注销</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>重启</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>待机</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>关机</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>返回</translation>
    </message>
</context>
<context>
    <name>MiniFrameNavigation</name>
    <message>
        <source>Computer</source>
        <translation>计算机</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>音乐</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>关机</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>锁定</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>注销</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>重启</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>待机</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>返回</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>文档</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>视频</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>图片</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>下载</translation>
    </message>
</context>
<context>
    <name>MiniFrameRightBar</name>
    <message>
        <source>Computer</source>
        <translation>计算机</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>音乐</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>下载</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>帮助手册</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>视频</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>图片</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>文档</translation>
    </message>
    <message>
        <source>Power</source>
        <translation>电源</translation>
    </message>
</context>
<context>
    <name>MiniFrameSwitchBtn</name>
    <message>
        <source>All Categories</source>
        <translation>所有分类</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>返回</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>确认</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall %1 ?</source>
        <translation>您确定要卸载 %1 吗？</translation>
    </message>
</context>
</TS>
